import React from 'react';
import { createTheme, ThemeProvider, CssBaseline } from '@mui/material';
import { grey, blue } from '@mui/material/colors';

// Enhanced theme with better visual hierarchy and modern styling
const theme = createTheme({
  palette: {
    mode: 'light',
    primary: {
      main: blue[700],
      dark: blue[900],
      light: blue[500],
      contrastText: '#fff'
    },
    background: {
      default: grey[100],
      paper: '#fff'
    }
  },
  typography: {
    h1: {
      fontSize: '2.5rem',
      fontWeight: 600,
      marginBottom: '1.5rem'
    },
    h2: {
      fontSize: '2rem',
      fontWeight: 500,
      marginBottom: '1.25rem'
    },
    h3: {
      fontSize: '1.75rem',
      fontWeight: 500,
      marginBottom: '1rem'
    }
  },
  components: {
    MuiButton: {
      styleOverrides: {
        root: {
          textTransform: 'none',
          borderRadius: 8,
          padding: '8px 16px',
          fontWeight: 500
        },
        contained: {
          boxShadow: 'none',
          '&:hover': {
            boxShadow: '0 2px 4px rgba(0,0,0,0.1)'
          }
        }
      }
    },
    MuiCard: {
      styleOverrides: {
        root: {
          borderRadius: 12,
          boxShadow: '0 2px 8px rgba(0,0,0,0.08)',
          '&:hover': {
            boxShadow: '0 4px 12px rgba(0,0,0,0.12)'
          }
        }
      }
    },
    MuiTextField: {
      styleOverrides: {
        root: {
          '& .MuiOutlinedInput-root': {
            borderRadius: 8,
            backgroundColor: '#fff',
            '&:hover fieldset': {
              borderColor: blue[400]
            }
          }
        }
      }
    },
    MuiTable: {
      styleOverrides: {
        root: {
          backgroundColor: '#fff',
          borderRadius: 12,
          overflow: 'hidden'
        }
      }
    },
    MuiTableHead: {
      styleOverrides: {
        root: {
          backgroundColor: grey[50]
        }
      }
    },
    MuiTableCell: {
      styleOverrides: {
        head: {
          fontWeight: 600,
          color: grey[900]
        }
      }
    }
  }
});

// Layout component for consistent padding and max-width
const Layout = ({ children }) => (
  <div className="p-6 max-w-7xl mx-auto">
    {children}
  </div>
);

// Enhanced page container with proper spacing and background
const PageContainer = ({ children, title }) => (
  <div className="min-h-screen bg-gray-100">
    <Layout>
      {title && <h1 className="text-3xl font-semibold mb-6">{title}</h1>}
      <div className="bg-white rounded-xl shadow-sm p-6">
        {children}
      </div>
    </Layout>
  </div>
);

export function EnhancedThemeProvider({ children }) {
    return (
      <ThemeProvider theme={theme}>
        <CssBaseline />
        {children}
      </ThemeProvider>
    );
  }
  
  export { Layout, PageContainer };
  export default EnhancedThemeProvider;  
